#!/bin/bash
#===============================================================================
#   lspkg.sh    |   Version 1.0     |   2-Clause BSD License    |   2014-03-04
#   James Hendrie                   |   hendrie dot james at gmail dot com
#===============================================================================

##  Global options
verbose=0

##  Print the help text
function print_help
{
	echo -e "Usage:  lspkg STRING\n"
	echo "Using this program is basically just a shortcut to typing"
	echo "ls /var/log/packages | grep -i STRING"
    echo -e "\nOptions:"
    echo -e "  -h or --help\t\tThis help text"
    echo -e "  -V or --version\tVersion and author info"
    echo -e "  -v\t\t\tEnable slightly more verbose output"
}


##  Print version and author info
function print_version
{
    echo "lspkg.sh, version 1.0"
    echo "James Hendrie (hendrie dot james at gmail dot com)"
}


##  Check for help / version long options
if [[ "$1" == "--help" ]]; then
    print_help
    exit 0
elif [[ "$1" == "--version" ]]; then
    print_version
    exit 0
fi

##  Get options
while getopts "hvV" flag; do
    if [[ "$flag" = "h" ]]; then
        print_help
        exit 0
    elif [[ "$flag" = "V" ]]; then
        print_version
        exit 0
    elif [[ "$flag" = "v" ]]; then
        let verbose=1
    fi
done

##  Find the index where we start counting 'after' recognized options
theIndex=$(( $# - $OPTIND + 1 ))
let theIndex=$(( $theIndex * -1 ))

##  For each argument after the last recognized option, do... everything.
for i in "${@:$theIndex}"; do

    if [[ $verbose -eq 1 ]]; then
        echo -e "\n========================================\n"
        ls /var/log/packages | grep -i "$i"
        echo -e "\n========================================\n"
    else
        ls /var/log/packages | grep -i "$i"
    fi

done
