#!/bin/bash
#===============================================================================
#   pkginfo.sh  |   Version 1.1     |   2-Clause BSD License    |   2014-04-11
#   James Hendrie                   |   hendrie dot james at gmail dot com
#===============================================================================

##  Check for correct number of packages
if [[ $# -ne 1 ]]; then
    echo "ERROR:  Only one package at a time, please" 2>&1
    exit 1
fi


##  Print help string
if [[ "$1" = "-h" ]] || [[ "$1" = "--help" ]]; then
    echo "Usage:  pkginfo STRING"
    echo -e "\nThis script will search for packages whose name matches STRING."
    echo "If more than one is found, it will print their names; if it gets a"
    echo "match, it will execute 'less /var/log/packages/PKG_NAME' so that you"
    echo "can get some information about that package."

    exit 0
fi

##  Print version / author info
if [[ "$1" = "-V" ]] || [[ "$1" = "--version" ]]; then
    echo "pkginfo version 1.1"
    echo "Written by James Hendrie (hendrie.james@gmail.com)"
    
    exit 0
fi

logDir=/var/log/packages

numPackages=$(ls "$logDir" | grep -i "$1" | wc -l)

if [[ $numPackages -gt 1 ]]; then
    echo -e "Avaialble packages:\n"
    ls "$logDir" | grep -i "$1"
    exit 0
elif [[ $numPackages -eq 0 ]]; then
    echo "ERROR:  No package names match string '$1'" 2>&1
    exit 1
else
    pkgName=$(ls "$logDir" | grep -i "$1" | head -n1)
    less "$logDir/$pkgName"
fi
